@@ -8,13 +8,12 @@ from wtforms.fields import (
     FieldList,
     FormField,
     TextField,
-    SelectMultipleField,
     _unset_value
 )
 from wtforms.validators import Optional, DataRequired
 
 
-__version__ = '0.2.0'
+__version__ = '0.2.1'
 
 
 class InvalidData(Exception):
@@ -57,9 +56,7 @@ def flatten_json(form, json, parent_key='', separator='-'):
                 .items()
             )
         elif isinstance(value, list):
-            if issubclass(field_class, SelectMultipleField):
-                items.append((new_key, value))
-            else:
+            if issubclass(field_class, FieldList):
                 items.extend(
                     flatten_json_list(
                         unbound_field.args[0],
@@ -68,6 +65,8 @@ def flatten_json(form, json, parent_key='', separator='-'):
                         separator
                     )
                 )
+            else:
+                items.append((new_key, value))
         else:
             items.append((new_key, value))
     return dict(items)
